@@ -1,6 +1,6 @@
 #smacof with linear constraints on the configuration (de Leeuw & Heiser, 1980; Borg & Groenen, p. 236)
 
-smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, weightmat = NULL, startconf = NULL, metric = TRUE,
+smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, weightmat = NULL, init = NULL, metric = TRUE,
                              ties = "primary", verbose = FALSE, modulus = 1, itmax = 1000, eps = 1e-6)
 {
 # diss ... dissimilarity matrix
@@ -8,7 +8,7 @@ smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, w
 # external ... external data for X-decomposition (Z in paper), or list with "simplex", or "circumplex"
 # weightmat ... weight structure. if not specified, weights is 1-structure
 # ndim ... number of dimensions
-# startconf ... starting configuration
+# init ... starting configuration
 # metric ... if TRUE, metric MDS, if FALSE, non-metric
 # ties ... ties for pava (primary, secondary, tertiary)
 # modulus ... modulus for nonmetric update
@@ -22,6 +22,8 @@ smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, w
   }
   p <- ndim                                     
   n <- attr(diss,"Size")
+  if (p > (n - 1)) stop("Maximum number of dimensions is n-1!")
+  
   nn <- n*(n-1)/2
   m <- length(diss)
   
@@ -59,13 +61,16 @@ smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, w
   
   if (is.null(weightmat)) {
     wgths <- initWeights(diss)
-  }  else  wgths <- weightmat
+  }  else  wgths <- as.dist(weightmat)
   
  
   dhat <- normDissN(diss,wgths,1)                  #normalize dissimilarities
   w <- vmat(wgths)                              #matrix V
   v <- myGenInv(w)                              #Moore-Penrose inverse
   itel <- 1
+
+  startconf <- init
+  if (!is.null(startconf)) startconf <- as.matrix(init)   # x as matrix with starting values   
   xstart <- startconf
 
   #----------- pre-specified functions for constraints -----------
@@ -130,8 +135,8 @@ smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, w
 	}
 	snon <- sum(wgths*(dhat-e)^2)                  #nonmetric stress
         
-	if (verbose) cat("Iteration: ",formatC(itel,width=3, format="d")," Stress: ",
-		formatC(c(sold,ssma,snon),digits=8,width=12,format="f"),"\n")
+	if (verbose) cat("Iteration: ",formatC(itel,width=3, format="d")," Stress (not normalized): ",
+		formatC(c(snon),digits=8,width=12,format="f"),"\n")
 
 	if (((sold-snon)<eps) || (itel == itmax)) break()   #convergence 
 
@@ -160,10 +165,12 @@ smacofConstraint <- function(delta, constraint = "linear", external, ndim = 2, w
   attr(dhat, "Labels") <- labels(diss)
   attr(e, "Labels") <- labels(diss)
   
-   confdiss <- normDissN(e, wgths, 1)        #final normalization to n(n-1)/2
+  confdiss <- normDissN(e, wgths, 1)        #final normalization to n(n-1)/2
 
-#return configurations, configuration distances, normalized observed distances 
-  result <- list(obsdiss = dhat, confdiss = confdiss, conf = y, stress.m = ssma, stress.nm = snon,
+  resmat <- as.matrix(dhat - confdiss)^2    #point stress
+  spp <- colMeans(resmat)
+
+  result <- list(delta = diss, obsdiss = dhat, confdiss = confdiss, conf = y, stress.m = ssma, stress.nm = snon, spp = spp,
                ndim = p, model = "SMACOF constraint", niter = itel, nobj = n, metric = metric, call = match.call()) 
   class(result) <- c("smacofB","smacof")
   result 
